@@ -624,7 +624,9 @@ def test_can_save_to_different_index(
 def test_save_without_skip_empty_will_include_empty_fields(
     write_client: Elasticsearch,
 ) -> None:
-    test_repo = Repository(field_1=[], field_2=None, field_3={}, meta={"id": 42})
+    test_repo = Repository(
+        field_1=[], field_2=None, field_3={}, owner={"name": None}, meta={"id": 42}
+    )
     assert test_repo.save(index="test-document", skip_empty=False)
 
     assert_doc_equals(
@@ -632,7 +634,12 @@ def test_save_without_skip_empty_will_include_empty_fields(
             "found": True,
             "_index": "test-document",
             "_id": "42",
-            "_source": {"field_1": [], "field_2": None, "field_3": {}},
+            "_source": {
+                "field_1": [],
+                "field_2": None,
+                "field_3": {},
+                "owner": {"name": None},
+            },
         },
         write_client.get(index="test-document", id=42),
     )
